#
# spec file for package jemalloc
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           jemalloc
Version:        3.4.1
Release:        3.13
%define lname	libjemalloc1
Summary:        General-purpose scalable concurrent malloc implementation
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
Url:            http://canonware.com/jemalloc/

#Git-Clone:	git://canonware.com/jemalloc
Source:         http://www.canonware.com/download/jemalloc/jemalloc-%{version}.tar.bz2
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt
Requires:       %lname = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
jemalloc is a general-purpose scalable concurrent malloc(3) implementation.
This package provides a shell wrapper script to run programs using jemalloc.

%package -n %lname
Summary:        General-purpose scalable concurrent malloc implementation
Group:          System/Libraries

%description -n %lname
General-purpose scalable concurrent malloc(3) implementation.
This distribution is the stand-alone "portable" version of jemalloc.

%package devel
Summary:        Development files for jemalloc
Group:          Development/Libraries/C and C++
Requires:       %lname = %{version}

%description devel
Headers for jemalloc, general-purpose scalable concurrent malloc(3)
implementation.

%package devel-static
Summary:        Static libraries for jemalloc
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description devel-static
Static libraries of jemalloc, general-purpose scalable concurrent
malloc(3) implementation.

%prep
%setup -q

%build
export CFLAGS="%{optflags} -g2";
%configure
make %{?_smp_mflags};

%install
b=%{buildroot};
make install DESTDIR="$b";

chmod -x "%{buildroot}/%{_libdir}"/*.a;
if [ "%_docdir" != "%{_datadir}/doc" ]; then
	# stupid Makefile does not allow to set it
	mkdir -p "$b/%_docdir";
	mv "$b/%{_datadir}/doc/jemalloc" "$b/%_docdir/%{name}";
fi;

mv %{buildroot}/%{_bindir}/pprof %{buildroot}/%{_bindir}/pprof-jemalloc

%check
make check

%files
%defattr(-,root,root)
%{_bindir}/jemalloc.sh
%{_bindir}/pprof-jemalloc
%{_mandir}/man*/*
%_docdir/%{name}

%files -n %lname
%defattr(-,root,root)
%{_libdir}/libjemalloc.so.1*

%files devel
%defattr(-,root,root,-)
%{_includedir}/jemalloc
%{_libdir}/libjemalloc.so

%files devel-static
%defattr(-,root,root,-)
%{_libdir}/libjemalloc*.a

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%changelog
* Tue Oct 22 2013 idonmez@suse.com
- Update to version 3.4.1
  * Fix a race in the "arenas.extend" mallctl that could cause memory
    corruption of internal data structures and subsequent crashes.
  * Fix Valgrind integration flaws that caused Valgrind warnings about
    reads of uninitialized memory in:
    + arena chunk headers
    + internal zero-initialized data structures
  * Preserve errno during the first allocation.  A readlink(2) call
    during initialization fails unless /etc/malloc.conf exists,
    so errno was typically set during the first allocation prior to this fix.
  * Fix compilation warnings reported by gcc 4.8.1
* Thu Jun  6 2013 idonmez@suse.com
- Rename pprof to pprof-jemalloc to prevent conflict with gperftools
* Wed Jun  5 2013 idonmez@suse.com
- Update to version 3.4.0
  * Support for aarch64
  * Fix race-triggered deadlocks in chunk_record()
* Thu Mar  7 2013 idonmez@suse.com
- Update to version 3.3.1
  * Fix a locking order bug that could cause deadlock during fork
    if heap profiling were enabled.
  * Fix a chunk recycling bug that could cause the allocator to lose
    track of whether a chunk was zeroed.
  * Fix TLS-related memory corruption that could occur during thread
    exit if the thread never allocated memory.  Only the quarantine
    and prof facilities were susceptible.
  * Internal reallocation of the quarantined object array leaked
    the old array.
  * Reallocation failure for internal reallocation of the quarantined
    object array (very unlikely) resulted in memory corruption.
  * Fix Valgrind integration to annotate all internally allocated
    memory in a way that keeps Valgrind happy about internal data
    structure access.
  * Fix building for s390 systems.
- Implement %%check
* Thu Jan 24 2013 idonmez@suse.com
- Update to version 3.3.0
  * Add clipping support to lg_chunk option processing.
  * Add the --enable-ivsalloc option.
  * Add the --without-export option.
  * Add the --disable-zone-allocator option.
  * Fix "arenas.extend" mallctl to output the number of arenas.
  * Fix chunk_recycyle() to unconditionally inform Valgrind that
    returned memory is undefined.
  * Fix build break on FreeBSD related to alloca.h.
* Wed Nov 14 2012 jengelh@inai.de
- Update to new upstream release 3.2.0
  * Fix deadlock in the "arenas.purge" mallctl.
- Update to new upstream release 3.1.0
  * Auto-detect whether running inside Valgrind, thus removing the
  need to manually specify MALLOC_CONF=valgrind:true.
  * Disable tcache by default if running inside Valgrind, in order to
  avoid making unallocated objects appear reachable to Valgrind.
  * Fix heap profiling crash if sampled object is freed via realloc(p, 0).
* Tue Sep  4 2012 jengelh@inai.de
- Update to new upstream release 3.0.0
  * Implement Valgrind support, redzones, and quarantine.
  * Add support for additional architectures: MIPS, SH4, Tilera
  * Add nallocm(), which rounds a request size up to the nearest size
  class without actually allocating.
  * Implement aligned_alloc()
  * Add the "thread.tcache.enabled" and "opt.prof_final" mallctls.
  * Update pprof (from gperftools 2.0).
  * (For more, see the ChangeLog file in this RPM package.)
* Thu Oct 13 2011 tony@daylessday.org
- Add a patch to generate jemalloc.sh during configure
* Wed Oct 12 2011 tony@daylessday.org
- Initial package (version 2.2.3) for build.opensuse.org
